.. _sample-configuration:

Sample configuration
====================

The following example is shipped as :file:`weblate/settings_example.py` with Weblate:

.. literalinclude:: ../../weblate/settings_example.py
    :language: python
